
From: David Teigland <teigland@redhat.com>

Adds the dlm to the build system.

Signed-off-by: Dave Teigland <teigland@redhat.com>
Signed-off-by: Patrick Caulfield <pcaulfie@redhat.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/Kconfig      |    2 ++
 drivers/Makefile     |    1 +
 drivers/dlm/Kconfig  |   27 +++++++++++++++++++++++++++
 drivers/dlm/Makefile |   23 +++++++++++++++++++++++
 4 files changed, 53 insertions(+)

diff -puN /dev/null drivers/dlm/Kconfig
--- /dev/null	2003-09-15 06:40:47.000000000 -0700
+++ devel-akpm/drivers/dlm/Kconfig	2005-09-12 03:34:38.000000000 -0700
@@ -0,0 +1,27 @@
+menu "Distributed Lock Manager"
+	depends on INET && EXPERIMENTAL
+
+config DLM
+	tristate "Distributed Lock Manager (DLM)"
+	select IP_SCTP
+	help
+	A general purpose distributed lock manager for kernel or userspace
+	applications.
+
+config DLM_DEVICE
+	tristate "DLM device for userspace access"
+	depends on DLM
+	help
+	This module creates a misc device through which the dlm lockspace
+	and locking functions become available to userspace applications
+	(usually through the libdlm library).
+
+config DLM_DEBUG
+	bool "DLM debugging"
+	depends on DLM
+	help
+	Under the debugfs mount point, the name of each lockspace will
+	appear as a file in the "dlm" directory.  The output is the
+	list of resource and locks the local node knows about.
+
+endmenu
diff -puN /dev/null drivers/dlm/Makefile
--- /dev/null	2003-09-15 06:40:47.000000000 -0700
+++ devel-akpm/drivers/dlm/Makefile	2005-09-12 03:34:38.000000000 -0700
@@ -0,0 +1,23 @@
+obj-$(CONFIG_DLM) +=		dlm.o
+obj-$(CONFIG_DLM_DEVICE) +=	dlm_device.o
+
+dlm-y :=			ast.o \
+				config.o \
+				dir.o \
+				lock.o \
+				lockspace.o \
+				lowcomms.o \
+				main.o \
+				member.o \
+				member_sysfs.o \
+				memory.o \
+				midcomms.o \
+				node_ioctl.o \
+				rcom.o \
+				recover.o \
+				recoverd.o \
+				requestqueue.o \
+				util.o
+dlm-$(CONFIG_DLM_DEBUG) +=	debug_fs.o
+
+dlm_device-y :=			device.o
diff -puN drivers/Kconfig~dlm-build drivers/Kconfig
--- devel/drivers/Kconfig~dlm-build	2005-09-12 03:34:38.000000000 -0700
+++ devel-akpm/drivers/Kconfig	2005-09-12 03:34:38.000000000 -0700
@@ -68,4 +68,6 @@ source "drivers/infiniband/Kconfig"
 
 source "drivers/sn/Kconfig"
 
+source "drivers/dlm/Kconfig"
+
 endmenu
diff -puN drivers/Makefile~dlm-build drivers/Makefile
--- devel/drivers/Makefile~dlm-build	2005-09-12 03:34:38.000000000 -0700
+++ devel-akpm/drivers/Makefile	2005-09-12 03:34:38.000000000 -0700
@@ -68,3 +68,4 @@ obj-$(CONFIG_INFINIBAND)	+= infiniband/
 obj-$(CONFIG_SGI_IOC4)		+= sn/
 obj-y				+= firmware/
 obj-$(CONFIG_CRYPTO)		+= crypto/
+obj-$(CONFIG_DLM)		+= dlm/
_
